Simd16

Struct Simd16 

#[repr(C)]
pub struct Simd16<T>(pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T);

Tuple Fields

0: T1: T2: T3: T4: T5: T6: T7: T8: T9: T10: T11: T12: T13: T14: T15: T