#[repr(C)]pub struct Simd32<T>(pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T, pub T);Tuple Fields
0: T1: T2: T3: T4: T5: T6: T7: T8: T9: T10: T11: T12: T13: T14: T15: T16: T17: T18: T19: T20: T21: T22: T23: T24: T25: T26: T27: T28: T29: T30: T31: TTrait Implementations
impl<T: Copy> Copy for Simd32<T>
impl<T: Safe> Safe for Simd32<T>